function plotNVM_ramme(a,b,X1,Nvb,Vvb,Mvb,X2,No,Vo,Mo,X3,Nhb,Vhb,Mhb,kurvmax,titelstreng)
%		 plotNVM_ramme(a,b,X1,Nvb,Vvb,Mvb,X2,No,Vo,Mo,X3,Nhb,Vhb,Mhb,kurvmax,titelstreng)
%-----------------------------------------------------------------------------------
% Plotter snitkrfter for en rammekonstruktion
%
% INPUT
%	a			Rammens hjde
%	b			Rammens halve bredde
%	X1			Koordinatakse for venstre rammeben startende i understtningen
%	Nvb,Vvb,Mvb	Snitkrfter i venstre rammeben
%	X2			Koordinatakse for overliggeren startende i venstre hjrne
%	No,Vo,Mo	Snitkrfter i overliggeren
%	X3			Koordinatakse for hjre rammeben startende i understtningen
%	Nhb,Vhb,Mhb Snitkrfter i hjre rammeben
%	kurvmax		Maksimal plotvrdi p kurverne. Bruges til at skalere plotsene
%	titelstreng Figurens titel
%-----------------------------------------------------------------------------------
% Johan Clausen
% Institut for Byggeri og Anlg
% lborg Universitet
% April 2010
%-----------------------------------------------------------------------------------
skala_NV = kurvmax/max(abs([Nvb ; No ; Nhb ; Vvb ; Vo ; Vhb])) ; % Skaleringsfaktor for normal- og forskydningskraft
subplot(3,1,1) ; hold on % Normalkraft
plot([0 0 2*b 2*b],[0 a a 0],'-k','linewidth',1.5) ; % Rammen
plot(b,a,'ok','MarkerFaceColor','w','MarkerSize',8) ; % Charnieret
plot([0 ; Nvb*skala_NV ; 0],[0 ; X1 ; a],'-g','linewidth',1.5) ; % Normalkraft i venstre rammeben
plot([0 ; X2 ; 2*b],[a ; -No*skala_NV + a ; a],'-g','linewidth',1.5) ; % Normalkraft i overligger
H(1) = plot([2*b ; -Nhb*skala_NV + 2*b ; 2*b],[0 ; X3 ; a],'-g','linewidth',1.5) ; % Normalkraft i hjre rammeben
axis([-kurvmax kurvmax+2*b 0 a+kurvmax]) ; % Aksegrnser sttes, sledes at rammen har samme strrelse p hver figur
title(titelstreng,'fontname','times','fontsize',14) ;
axis off
axis equal

subplot(3,1,2) ; hold on % Forskydningskraft
plot([0 0 2*b 2*b],[0 a a 0],'-k','linewidth',1.5) ; % Rammen
plot(b,a,'ok','MarkerFaceColor','w','MarkerSize',8) ; % Charnieret
plot([0 ; -Vvb*skala_NV ; 0],[0 ; X1 ; a],'-r','linewidth',1.5) ; % Forskydningskraft i venstre rammeben
plot([0 ; X2 ; 2*b],[a ; -Vo*skala_NV + a ; a],'-r','linewidth',1.5) ; % Forskydningskraft i overligger
H(2) = plot([2*b ; Vhb*skala_NV + 2*b ; 2*b],[0 ; X3 ; a],'-r','linewidth',1.5) ; % Forskydningskraft i hjre rammeben
axis([-kurvmax kurvmax+2*b 0 a+kurvmax]) ; % Aksegrnser sttes, sledes at rammen har samme strrelse p hver figur
axis off
axis equal

skala_M = kurvmax/max(abs([Mvb ; Mo ; Mhb])) ; % Skaleringsfaktor for moment
subplot(3,1,3) ; hold on % Moment
plot([0 0 2*b 2*b],[0 a a 0],'-k','linewidth',1.5) ; % Rammen
plot(b,a,'ok','MarkerFaceColor','w','MarkerSize',8) ; % Charnieret
plot([0 ; Mvb*skala_M ; 0],[0 ; X1 ; a],'-b','linewidth',1.5) ; % Moment i venstre rammeben
plot([0 ; X2 ; 2*b],[a ; -Mo*skala_M + a ; a],'-b','linewidth',1.5) ; % Moment i overligger
H(3) = plot([2*b ; -Mhb*skala_M + 2*b ; 2*b],[0 ; X3 ; a],'-b','linewidth',1.5) ; % Moment i hjre rammeben
axis([-kurvmax kurvmax+2*b 0 a+kurvmax]) ; % Aksegrnser sttes, sledes at rammen har samme strrelse p hver figur
axis off
axis equal

legend_handle = legend(H,'\it{N}','\it{V}','\it{M}','Location','Best') ;
%----- slut ------------------------------------------------------------------------------